!!! note
    Audiobooks are only available for the US, UK, Ireland, New Zealand and Australia markets.

::: spotify.api.API
    options:
      members:
        - get_audiobook
        - get_several_audiobooks
        - get_audiobook_chapters
        - get_users_saved_audiobooks
        - save_audiobooks_for_user
        - remove_users_saved_audiobooks
        - check_users_saved_audiobooks
::: spotify.models.SimpleAudiobook
::: spotify.models.Audiobook
::: spotify.models.Author
::: spotify.models.Narrator
